@@ -15,7 +15,7 @@ from .macros import macros, document, filter_class  # noqa: F401
 from .out_base import BoMRegex
 from . import log
 
-logger = log.get_logger(__name__)
+logger = log.get_logger()
 
 
 class DNFList(Optionable):
@@ -30,7 +30,7 @@ class Generic(BaseFilter):  # noqa: F821
     """ Generic filter
         This filter is based on regular expressions.
         It also provides some shortcuts for common situations.
-        Note that matches aren't case sensitive and spaces at the beggining and the end are removed.
+        Note that matches aren't case sensitive and spaces at the beginning and the end are removed.
         The internal `_mechanical` filter emulates the KiBoM behavior for default exclusions.
         The internal `_kicost_dnp` filter emulates KiCost's `dnp` field """
     def __init__(self):
@@ -53,7 +53,7 @@ class Generic(BaseFilter):  # noqa: F821
             self.exclude_value = False
             """ Exclude components if their 'Value' is any of the keys """
             self.config_field = 'Config'
-            """ Name of the field used to clasify components """
+            """ Name of the field used to classify components """
             self.config_separators = ' ,'
             """ Characters used to separate options inside the config field """
             self.exclude_config = False
@@ -124,6 +124,10 @@ class Generic(BaseFilter):  # noqa: F821
             if reg.skip_if_no_field and not c.is_field(reg.column):
                 # Skip the check if the field doesn't exist
                 continue
+            if reg.match_if_field and c.is_field(reg.column):
+                return True
+            if reg.match_if_no_field and not c.is_field(reg.column):
+                return True
             field_value = c.get_field_value(reg.column)
             res = reg.regex.search(field_value)
             if reg.invert:
@@ -145,6 +149,10 @@ class Generic(BaseFilter):  # noqa: F821
             if reg.skip_if_no_field and not c.is_field(reg.column):
                 # Skip the check if the field doesn't exist
                 continue
+            if reg.match_if_field and c.is_field(reg.column):
+                return True
+            if reg.match_if_no_field and not c.is_field(reg.column):
+                return True
             field_value = c.get_field_value(reg.column)
             res = reg.regex.search(field_value)
             if reg.invert:
