@@ -103,6 +103,7 @@ def path_stats(path, _stats_cache=None):
 
     Beside the source file `path` itself, we look at any macro definition files
     the source file imports macros from, recursively, in a `make`-like fashion.
+    Dialect-imports, if any, are treated the same way.
 
     `_stats_cache` is used internally to speed up the computation, in case the
     dependency graph hits the same source file multiple times.
@@ -155,7 +156,7 @@ def path_stats(path, _stats_cache=None):
         # TODO: Or just document it, that the dialect definition module *must* macro-import those macros
         # TODO: even if it just injects them in the template?
         with tokenize.open(path) as sourcefile:
-            tree = ast.parse(sourcefile.read())
+            tree = ast.parse(sourcefile.read(), filename=path)
 
         macroimports = []
         dialectimports = []
@@ -165,7 +166,7 @@ def path_stats(path, _stats_cache=None):
                     macroimports.append(stmt)
                 elif ismacroimport(stmt, magicname="dialects"):
                     dialectimports.append(stmt)
-                elif iswithphase(stmt):  # for multi-phase compilation: scan also inside top-level `with phase`
+                elif iswithphase(stmt, filename=path):  # for multi-phase compilation: scan also inside top-level `with phase`
                     scan(stmt)
         scan(tree)
 
