@@ -7,7 +7,7 @@ import ast
 from copy import deepcopy
 
 from .astfixers import fix_locations
-from .coreutils import ismacroimport
+from .coreutils import ismacroimport, split_futureimports
 from .markers import ASTMarker
 from .utils import getdocstring
 from .walkers import ASTTransformer
@@ -46,7 +46,6 @@ def splice_expression(expr, template, tag="__paste_here__"):
 
     Returns `template` with `expr` spliced in. Note `template` is **not** copied,
     and will be mutated in-place.
-
     """
     if not template:
         return expr
@@ -58,7 +57,7 @@ def splice_expression(expr, template, tag="__paste_here__"):
         raise TypeError(f"`template` must be an AST or `list`; got {type(template)} with value {repr(template)}")
 
     def ispastehere(tree):
-        return type(tree) is ast.Expr and type(tree.value) is ast.Name and tree.value.id == tag
+        return type(tree) is ast.Name and tree.id == tag
 
     class ExpressionSplicer(ASTTransformer):
         def __init__(self):
@@ -158,29 +157,64 @@ def splice_statements(body, template, tag="__paste_here__"):
     return StatementSplicer().visit(template)
 
 
-def splice_dialect(body, template, tag="__paste_here__"):
+def splice_dialect(body, template, tag="__paste_here__", lineno=None, col_offset=None):
     """In a dialect AST transformer, splice module `body` into `template`.
 
     On top of what `splice_statements` does, this function handles macro-imports
     and dialect-imports specially, gathering them all at the top level of the
     final module body, so that mcpyrate sees them when the module is sent to
-    the macro expander.
+    the macro expander. This is to allow a dialect template to splice the body
+    into the inside of a `with` block (e.g. to invoke some code-walking macro
+    that changes the language semantics, such as an auto-TCO or a lazifier),
+    without breaking macro-imports (and further dialect-imports) introduced
+    by user code in the body.
 
     Any dialect-imports in the template are placed first (in the order they
     appear in the template), followed by any dialect-imports in the user code
     (in the order they appear in the user code), followed by macro-imports in
     the template, then macro-imports in the user code.
 
-    This also handles the module docstring and the magic `__all__` (if any)
-    from `body`. The docstring comes first, before dialect-imports. The magic
-    `__all__` is placed after dialect-imports, before macro-imports.
+    We also handle the module docstring, future-imports, and the magic `__all__`.
+
+    The optional `lineno` and `col_offset` parameters can be used to tell
+    `splice_dialect` the source location info of the dialect-import (in the
+    unexpanded source code) that triggered this template. If specified, they
+    are used to mark all the lines coming from the template as having come
+    from that dialect-import statement. During dialect expansion, you can
+    get these from the `lineno` and `col_offset` attributes of your dialect
+    instance (these attributes are filled in by `DialectExpander`).
+
+    If both `body` and `template` have a module docstring, they are concatenated
+    to produce the module docstring for the result. If only one of them has a
+    module docstring, that docstring is used as-is. If neither has a module docstring,
+    the docstring is omitted.
+
+    The primary use of a module docstring in a dialect template is to be able to say
+    that the program was written in dialect X, more information on which can be found at...
+
+    Future-imports from `template` and `body` are concatenated.
+
+    The magic `__all__` is taken from `body`; if `body` does not define it,
+    it is omitted.
+
+    In the result, the ordering is::
+
+        docstring
+        template future-imports
+        body future-imports
+        __all__ (if defined in body)
+        template dialect-imports
+        body dialect-imports
+        template macro-imports
+        body macro-imports
+        the rest
 
     Parameters:
 
-        `body`: `list` of statements
+        `body`: `list` of `ast.stmt`, or a single `ast.stmt`
             Original module body from the user code (input).
 
-        `template`: `list` of statements
+        `template`: `list` of `ast.stmt`, or a single `ast.stmt`
             Template for the final module body (output).
 
             Must contain a paste-here indicator as in `splice_statements`.
@@ -188,16 +222,19 @@ def splice_dialect(body, template, tag="__paste_here__"):
         `tag`: `str`
             The name of the paste-here indicator in `template`.
 
-    Returns `template` with `body` spliced in. Note `template` is **not** copied,
-    and will be mutated in-place.
+        `lineno`: optional `int`
+        `col_offset`: optional `int`
+            Source location info of the dialect-import that triggered this template.
 
-    Also `body` is mutated, to remove macro-imports, `__all__` and the module
-    docstring; these are pasted into the final result.
+    Return value is `template` with `body` spliced in.
+
+    Note `template` and `body` are **not** copied, and **both** will be mutated
+    during the splicing process.
     """
     if isinstance(body, ast.AST):
         body = [body]
     if isinstance(template, ast.AST):
-        body = [template]
+        template = [template]
     if not body:
         raise ValueError("expected at least one statement in `body`")
     if not template:
@@ -208,20 +245,34 @@ def splice_dialect(body, template, tag="__paste_here__"):
     # Even if they have location info, it's for a different file compared
     # to the use site where `body` comes from.
     #
-    # Pretend the template code appears at the beginning of the user module.
-    #
-    # TODO: It would be better to pretend it appears at the line that has the dialect-import.
-    # TODO: Requires a `lineno` parameter here, and `DialectExpander` must be modified to supply it.
-    # TODO: We could extract the `lineno` in `find_dialectimport_ast` and then pass it to the
-    # TODO: user-defined dialect AST transformer, so it could pass it to us if it wants to.
-    for stmt in template:
-        fix_locations(stmt, body[0], mode="overwrite")
-
-    if getdocstring(body):
-        docstring, *body = body
-        docstring = [docstring]
+    # Pretend the template code appears at the given source location,
+    # or if not given, at the beginning of `body`.
+    if lineno is not None and col_offset is not None:
+        srcloc_dummynode = ast.Constant(value=None)
+        srcloc_dummynode.lineno = lineno
+        srcloc_dummynode.col_offset = col_offset
     else:
-        docstring = []
+        srcloc_dummynode = body[0]
+    for stmt in template:
+        fix_locations(stmt, srcloc_dummynode, mode="overwrite")
+
+    user_docstring, user_futureimports, body = split_futureimports(body)
+    template_docstring, template_futureimports, template = split_futureimports(template)
+
+    # Combine user and template docstrings if both are defined.
+    if user_docstring and template_docstring:
+        # We must extract the bare strings, combine them, and then pack the result into an AST node.
+        user_doc = getdocstring(user_docstring)
+        template_doc = getdocstring(template_docstring)
+        sep = "\n" + ("-" * 79) + "\n"
+        new_doc = user_doc + sep + template_doc
+        new_docstring = ast.copy_location(ast.Constant(value=new_doc),
+                                          user_docstring[0])
+        docstring = [new_docstring]
+    else:
+        docstring = user_docstring or template_docstring
+
+    futureimports = template_futureimports + user_futureimports
 
     def extract_magic_all(tree):
         def ismagicall(tree):
@@ -240,6 +291,7 @@ def splice_dialect(body, template, tag="__paste_here__"):
         w.visit(tree)
         return tree, w.collected
     body, user_magic_all = extract_magic_all(body)
+    template, ignored_template_magic_all = extract_magic_all(template)
 
     def extract_macroimports(tree, *, magicname="macros"):
         class MacroImportExtractor(ASTTransformer):
@@ -258,6 +310,7 @@ def splice_dialect(body, template, tag="__paste_here__"):
 
     finalbody = splice_statements(body, template, tag)
     return (docstring +
+            futureimports +
             user_magic_all +
             template_dialect_imports + user_dialect_imports +
             template_macro_imports + user_macro_imports +
