@@ -77,6 +77,8 @@ CMD_PCBNEW_3D = CMD_PCBNEW_RUN_DRC
 URL_PCBNEW_3D = URL_EESCHEMA_DO
 CMD_PCBNEW_GENCAD = CMD_PCBNEW_RUN_DRC
 URL_PCBNEW_GENCAD = URL_EESCHEMA_DO
+CMD_PCBNEW_IPC_NETLIST = CMD_PCBNEW_RUN_DRC
+URL_PCBNEW_IPC_NETLIST = URL_EESCHEMA_DO
 CMD_KIBOM = 'KiBOM_CLI.py'
 URL_KIBOM = 'https://github.com/INTI-CMNB/KiBoM'
 CMD_IBOM = 'generate_interactive_bom.py'
@@ -93,6 +95,7 @@ PANDOC = 'pandoc'
 KICAD_VERSION_5_99 = 5099000
 KICAD_VERSION_6_0_0 = 6000000
 KICAD_VERSION_6_0_2 = 6000002
+TRY_INSTALL_CHECK = 'Try running the installation checker: kibot-check'
 
 # Internal filter names
 IFILT_MECHANICAL = '_mechanical'
@@ -291,3 +294,75 @@ def hide_stderr():
     os.close(devnull)
     yield
     os.dup2(newstderr, 2)
+
+
+class ToolDependencyRole(object):
+    """ Class used to define the role of a tool """
+    def __init__(self, desc=None, version=None, output=None):
+        # Is this tool mandatory
+        self.mandatory = desc is None
+        # If not mandatory, for what?
+        self.desc = desc
+        # Which version is needed?
+        self.version = version
+        # Which output needs it?
+        self.output = output
+
+
+class ToolDependency(object):
+    """ Class used to define tools needed for an output """
+    def __init__(self, output, name, url=None, url_down=None, is_python=False, deb=None, in_debian=True, extra_deb=None,
+                 roles=None, plugin_dirs=None, command=None, pypi_name=None, module_name=None, no_cmd_line_version=False,
+                 help_option=None, no_cmd_line_version_old=False):
+        # The associated output
+        self.output = output
+        # Name of the tool
+        self.name = name
+        # Name of the .deb
+        if deb is None:
+            if is_python:
+                self.deb_package = 'python3-'+name.lower()
+            else:
+                self.deb_package = name.lower()
+        else:
+            self.deb_package = deb
+        self.is_python = is_python
+        if is_python:
+            self.module_name = module_name if module_name is not None else name.lower()
+        # If this tool has an official Debian package
+        self.in_debian = in_debian
+        # Name at PyPi, can be fake for things that aren't at PyPi
+        # Is used just to indicate if a dependency will we installed from PyPi
+        self.pypi_name = pypi_name if pypi_name is not None else name
+        # Extra Debian packages needed to complement it
+        self.extra_deb = extra_deb
+        # URLs
+        self.url = url
+        self.url_down = url_down
+        # Can be installed as a KiCad plug-in?
+        self.is_kicad_plugin = plugin_dirs is not None
+        self.plugin_dirs = plugin_dirs
+        # Command we run
+        self.command = command if command is not None else name.lower()
+        self.no_cmd_line_version = no_cmd_line_version
+        self.no_cmd_line_version_old = no_cmd_line_version_old  # An old version doesn't have version
+        self.help_option = help_option if help_option is not None else '--version'
+        # Roles
+        if roles is None:
+            roles = [ToolDependencyRole()]
+        elif not isinstance(roles, list):
+            roles = [roles]
+        for r in roles:
+            r.output = output
+        self.roles = roles
+
+
+def kiauto_dependency(output, version=None):
+    role = None if version is None else ToolDependencyRole(version=version)
+    return ToolDependency(output, 'KiCad Automation tools', URL_EESCHEMA_DO, url_down=URL_EESCHEMA_DO+'/releases',
+                          in_debian=False, pypi_name='kiauto', command='pcbnew_do', roles=role)
+
+
+def git_dependency(output):
+    return ToolDependency(output, 'Git', 'https://git-scm.com/',
+                          roles=ToolDependencyRole(desc='Find commit hash and/or date'))
