@@ -7,9 +7,8 @@ from pcbnew import PLOT_FORMAT_DXF, SKETCH, FILLED
 from .out_any_layer import AnyLayer
 from .drill_marks import DrillMarks
 from .gs import GS
-from .misc import KICAD_VERSION_5_99
 from .macros import macros, document, output_class  # noqa: F401
-if GS.kicad_version_n >= KICAD_VERSION_5_99:  # pragma: no cover (Ki6)
+if GS.ki6():
     from pcbnew import DXF_UNITS_MILLIMETERS, DXF_UNITS_INCHES
 else:
     DXF_UNITS_MILLIMETERS = 1
@@ -34,7 +33,7 @@ class DXFOptions(DrillMarks):
         super()._configure_plot_ctrl(po, output_dir)
         po.SetDXFPlotPolygonMode(self.polygon_mode)
         # DXF_PLOTTER::DXF_UNITS isn't available
-        # According to https://docs.kicad-pcb.org/doxygen/classDXF__PLOTTER.html 1 is mm
+        # According to https://docs.kicad.org/doxygen/classDXF__PLOTTER.html 1 is mm
         po.SetDXFPlotUnits(DXF_UNITS_MILLIMETERS if self.metric_units else DXF_UNITS_INCHES)
         po.SetPlotMode(SKETCH if self.sketch_plot else FILLED)
         po.SetUseAuxOrigin(self.use_aux_axis_as_origin)
