@@ -11,8 +11,9 @@ from shutil import which
 
 from .gs import GS
 from .misc import (UI_SMD, UI_VIRTUAL, MOD_THROUGH_HOLE, MOD_SMD, MOD_EXCLUDE_FROM_POS_FILES, PANDOC, MISSING_TOOL,
-                   FAILED_EXECUTE, W_WRONGEXT, W_WRONGOAR, W_ECCLASST, W_MISSTOOL)
-from .registrable import RegOutput
+                   FAILED_EXECUTE, W_WRONGEXT, W_WRONGOAR, W_ECCLASST, W_MISSTOOL, ToolDependency, ToolDependencyRole,
+                   TRY_INSTALL_CHECK)
+from .registrable import RegOutput, RegDependency
 from .out_base import BaseOptions
 from .error import KiPlotConfigurationError
 from .kiplot import config_output
@@ -23,6 +24,10 @@ logger = log.get_logger()
 INF = float('inf')
 PANDOC_INSTALL = ("In CI/CD environments: the `kicad_auto_test` docker image contains it.\n"
                   "In Debian/Ubuntu environments: install `pandoc`, `texlive-latex-base` and `texlive-latex-recommended`")
+RegDependency.register(ToolDependency('report', 'Pandoc', 'https://pandoc.org/',
+                                      url_down='https://github.com/jgm/pandoc/releases',
+                                      extra_deb=['texlive-latex-base', 'texlive-latex-recommended'],
+                                      roles=ToolDependencyRole(desc='Create PDF/ODF/DOCX files')))
 
 
 def do_round(v, dig):
@@ -718,6 +723,7 @@ class ReportOptions(BaseOptions):
         except FileNotFoundError:
             logger.error("Unable to convert the report, `{}` must be installed.".format(PANDOC))
             logger.error(PANDOC_INSTALL)
+            logger.error(TRY_INSTALL_CHECK)
             exit(MISSING_TOOL)
         except CalledProcessError as e:
             logger.error('{} error: {}'.format(PANDOC, e.returncode))
@@ -799,6 +805,7 @@ class Report(BaseOutput):  # noqa: F821
     def get_conf_examples(name, layers, templates):
         if which(PANDOC) is None:
             logger.warning((W_MISSTOOL+'Missing {} tool, disabling report in PDF format\n'+PANDOC_INSTALL).format(PANDOC))
+            logger.warning(W_MISSTOOL+TRY_INSTALL_CHECK)
             pandoc = False
         else:
             pandoc = True
