@@ -9,7 +9,6 @@ from pcbnew import (PLOT_FORMAT_SVG, FromMM, ToMM)
 from .out_any_layer import AnyLayer
 from .drill_marks import DrillMarks
 from .gs import GS
-from .misc import KICAD_VERSION_5_99
 from .macros import macros, document, output_class  # noqa: F401
 
 
@@ -28,13 +27,13 @@ class SVGOptions(DrillMarks):
     def _configure_plot_ctrl(self, po, output_dir):
         super()._configure_plot_ctrl(po, output_dir)
         po.SetMirror(self.mirror_plot)
-        if GS.kicad_version_n < KICAD_VERSION_5_99:
+        if GS.ki5():
             po.SetLineWidth(FromMM(self.line_width))
         po.SetNegative(self.negative_plot)
 
     def read_vals_from_po(self, po):
         super().read_vals_from_po(po)
-        if GS.kicad_version_n < KICAD_VERSION_5_99:
+        if GS.ki5():
             self.line_width = ToMM(po.GetLineWidth())
         self.negative_plot = po.GetNegative()
         self.mirror_plot = po.GetMirror()
@@ -45,7 +44,8 @@ class SVG(AnyLayer):
     """ SVG (Scalable Vector Graphics)
         Exports the PCB to a format suitable for 2D graphics software.
         Unlike bitmaps SVG drawings can be scaled without losing resolution.
-        This output is what you get from the File/Plot menu in pcbnew. """
+        This output is what you get from the File/Plot menu in pcbnew.
+        The `pcb_print` is usually a better alternative. """
     def __init__(self):
         super().__init__()
         with document:
